@@ -39,14 +39,15 @@ ogs_sock_t *ngap_server(ogs_socknode_t *node)
 
 #if HAVE_USRSCTP
     sock = ogs_sctp_server(SOCK_SEQPACKET, node);
-    ogs_assert(sock);
+    if (!sock) return NULL;
     usrsctp_set_non_blocking((struct socket *)sock, 1);
     usrsctp_set_upcall((struct socket *)sock, usrsctp_recv_handler, NULL);
 #else
     sock = ogs_sctp_server(SOCK_STREAM, node);
-    ogs_assert(sock);
+    if (!sock) return NULL;
     node->poll = ogs_pollset_add(ogs_app()->pollset,
             OGS_POLLIN, sock->fd, lksctp_accept_handler, sock);
+    ogs_assert(node->poll);
 #endif
 
     ogs_info("ngap_server() [%s]:%d",
