@@ -251,7 +251,7 @@ int sgwu_gtp_open(void)
 
     ogs_list_for_each(&ogs_gtp_self()->gtpu_list, node) {
         sock = ogs_gtp_server(node);
-        ogs_assert(sock);
+        if (!sock) return OGS_ERROR;
 
         if (sock->family == AF_INET)
             ogs_gtp_self()->gtpu_sock = sock;
@@ -260,6 +260,7 @@ int sgwu_gtp_open(void)
 
         node->poll = ogs_pollset_add(ogs_app()->pollset,
                 OGS_POLLIN, sock->fd, _gtpv1_u_recv_cb, sock);
+        ogs_assert(node->poll);
     }
 
     OGS_SETUP_GTPU_SERVER;
