@@ -56,15 +56,9 @@ void udm_state_operational(ogs_fsm_t *s, udm_event_t *e)
 
     switch (e->id) {
     case OGS_FSM_ENTRY_SIG:
-        rv = udm_sbi_open();
-        if (rv != OGS_OK) {
-            ogs_fatal("Can't establish SBI path");
-        }
-
         break;
 
     case OGS_FSM_EXIT_SIG:
-        udm_sbi_close();
         break;
 
     case UDM_EVT_SBI_SERVER:
@@ -308,14 +302,16 @@ void udm_state_operational(ogs_fsm_t *s, udm_event_t *e)
 
                 udm_ue = (udm_ue_t *)sbi_xact->sbi_object;
                 ogs_assert(udm_ue);
+
+                e->sbi.data = sbi_xact->assoc_stream;
+
+                ogs_sbi_xact_remove(sbi_xact);
+
                 udm_ue = udm_ue_cycle(udm_ue);
                 ogs_assert(udm_ue);
 
                 e->udm_ue = udm_ue;
                 e->sbi.message = &message;
-                e->sbi.data = sbi_xact->assoc_stream;
-
-                ogs_sbi_xact_remove(sbi_xact);
 
                 ogs_fsm_dispatch(&udm_ue->sm, e);
                 if (OGS_FSM_CHECK(&udm_ue->sm, udm_ue_state_exception)) {
